@@ -10,19 +10,34 @@
 $replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
 if ( strtr($_SERVER['SCRIPT_FILENAME'], $replace_array) === strtr(__FILE__, '\\', '/') )  exit;
 
-//*****************************************************************************/
-// mainfile.phpɤ߹
-//*****************************************************************************/
 if( ! defined( 'XOOPS_ROOT_PATH' ) ) {
+	//*************************************************************************/ 
+	// ⥸塼뤬󥹥ȡ뤵Ƥʤ˥Ǥ顼޻
+	//*************************************************************************/ 
+	$display_errors = ini_get( 'display_errors' );
+	ini_set( 'display_errors', false );
+
+	//*************************************************************************/ 
+	// mainfile.phpɤ߹
+	//*************************************************************************/ 
 	$root_path_dir = dirname( dirname(dirname(dirname(__FILE__))) );
 	include_once( $root_path_dir .'/mainfile.php' );
+
+	//*************************************************************************/ 
+	// Ǥ顼޻ߤ
+	//*************************************************************************/ 
+	$display_errors = ini_get( 'display_errors' );
+	ini_set( 'display_errors', $display_errors );
 }
 
 //*****************************************************************************/
 // ⥸塼ROOT_PATHURLꤹDuplicatableˤ뤿ˤϤʤ
 //*****************************************************************************/
 $mod_path = dirname( dirname(__FILE__) );
-$mod_url = str_replace( XOOPS_ROOT_PATH, XOOPS_URL, strtr($mod_path, '\\', '/') );
-$mod_name = basename(dirname(dirname(__FILE__)));
+$replace_array = array( '\\' => '/', '\\.\\' => '/', '/./' => '/' );
+$mod_replace_path = strtr( $mod_path, $replace_array );
+$xoops_root_path = strtr( XOOPS_ROOT_PATH, $replace_array );
+$mod_url = ( str_replace($xoops_root_path, XOOPS_URL, strtr($mod_replace_path, '\\', '/')) );
+$mod_name = basename( dirname(dirname(__FILE__)) );
 
 ?>
\ No newline at end of file
